@@ -1,14 +1,15 @@
 from concurrent.futures import Future
+import os
 import unittest
 from time import sleep
 from queue import Queue
 
 from executorlib import Executor
-from executorlib.shared.executor import cloudpickle_register
-from executorlib.interactive import create_executor
-from executorlib.shared.thread import RaisingThread
-from executorlib.shared.executor import execute_tasks_with_dependencies
-from executorlib.shared.plot import generate_nodes_and_edges
+from executorlib.interactive.executor import create_executor
+from executorlib.interactive.shared import execute_tasks_with_dependencies
+from executorlib.standalone.plot import generate_nodes_and_edges
+from executorlib.standalone.serialize import cloudpickle_register
+from executorlib.standalone.thread import RaisingThread
 
 
 try:
@@ -41,7 +42,7 @@ def merge(lst):
 
 class TestExecutorWithDependencies(unittest.TestCase):
     def test_executor(self):
-        with Executor(max_cores=1, backend="local", hostname_localhost=True) as exe:
+        with Executor(max_cores=1, backend="local") as exe:
             cloudpickle_register(ind=1)
             future_1 = exe.submit(add_function, 1, parameter_2=2)
             future_2 = exe.submit(add_function, 1, parameter_2=future_1)
@@ -55,7 +56,6 @@ class TestExecutorWithDependencies(unittest.TestCase):
         with Executor(
             max_cores=1,
             backend="local",
-            hostname_localhost=True,
             plot_dependency_graph=True,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -74,6 +74,30 @@ class TestExecutorWithDependencies(unittest.TestCase):
             self.assertEqual(len(nodes), 5)
             self.assertEqual(len(edges), 4)
 
+    @unittest.skipIf(
+        skip_graphviz_test,
+        "graphviz is not installed, so the plot_dependency_graph tests are skipped.",
+    )
+    def test_executor_dependency_plot_filename(self):
+        graph_file = os.path.join(os.path.dirname(__file__), "test.png")
+        with Executor(
+            max_cores=1,
+            backend="local",
+            plot_dependency_graph=False,
+            plot_dependency_graph_filename=graph_file,
+        ) as exe:
+            cloudpickle_register(ind=1)
+            future_1 = exe.submit(add_function, 1, parameter_2=2)
+            future_2 = exe.submit(add_function, 1, parameter_2=future_1)
+            self.assertTrue(future_1.done())
+            self.assertTrue(future_2.done())
+        self.assertTrue(os.path.exists(graph_file))
+        os.remove(graph_file)
+
+    def test_create_executor_error(self):
+        with self.assertRaises(ValueError):
+            create_executor(backend="toast", resource_dict={"cores": 1})
+
     def test_dependency_steps(self):
         cloudpickle_register(ind=1)
         fs1 = Future()
@@ -100,12 +124,15 @@ class TestExecutorWithDependencies(unittest.TestCase):
         executor = create_executor(
             max_workers=1,
             max_cores=2,
-            cores_per_worker=1,
-            threads_per_core=1,
-            gpus_per_worker=0,
-            openmpi_oversubscribe=False,
+            resource_dict={
+                "cores": 1,
+                "threads_per_core": 1,
+                "gpus_per_core": 0,
+                "cwd": None,
+                "openmpi_oversubscribe": False,
+                "slurm_cmd_args": [],
+            },
             backend="local",
-            hostname_localhost=True,
         )
         process = RaisingThread(
             target=execute_tasks_with_dependencies,
@@ -127,7 +154,7 @@ class TestExecutorWithDependencies(unittest.TestCase):
     def test_many_to_one(self):
         length = 5
         parameter = 1
-        with Executor(max_cores=2, backend="local", hostname_localhost=True) as exe:
+        with Executor(max_cores=2, backend="local") as exe:
             cloudpickle_register(ind=1)
             future_lst = exe.submit(
                 generate_tasks,
@@ -162,7 +189,6 @@ class TestExecutorWithDependencies(unittest.TestCase):
         with Executor(
             max_cores=2,
             backend="local",
-            hostname_localhost=True,
             plot_dependency_graph=True,
         ) as exe:
             cloudpickle_register(ind=1)
