@@ -47,7 +47,7 @@ class TestFluxBackend(unittest.TestCase):
         with Executor(
             max_cores=2,
             flux_executor=self.executor,
-            backend="flux",
+            backend="flux_allocation",
             block_allocation=True,
         ) as exe:
             fs_1 = exe.submit(calc, 1)
@@ -60,9 +60,9 @@ class TestFluxBackend(unittest.TestCase):
     def test_flux_executor_threads(self):
         with Executor(
             max_cores=1,
-            threads_per_core=2,
+            resource_dict={"threads_per_core": 2},
             flux_executor=self.executor,
-            backend="flux",
+            backend="flux_allocation",
             block_allocation=True,
         ) as exe:
             fs_1 = exe.submit(calc, 1)
@@ -75,9 +75,9 @@ class TestFluxBackend(unittest.TestCase):
     def test_flux_executor_parallel(self):
         with Executor(
             max_cores=2,
-            cores_per_worker=2,
+            resource_dict={"cores": 2},
             flux_executor=self.executor,
-            backend="flux",
+            backend="flux_allocation",
             block_allocation=True,
             flux_executor_pmi_mode=pmi,
         ) as exe:
@@ -88,9 +88,9 @@ class TestFluxBackend(unittest.TestCase):
     def test_single_task(self):
         with Executor(
             max_cores=2,
-            cores_per_worker=2,
+            resource_dict={"cores": 2},
             flux_executor=self.executor,
-            backend="flux",
+            backend="flux_allocation",
             block_allocation=True,
             flux_executor_pmi_mode=pmi,
         ) as p:
@@ -100,16 +100,70 @@ class TestFluxBackend(unittest.TestCase):
             [[(1, 2, 0), (1, 2, 1)], [(2, 2, 0), (2, 2, 1)], [(3, 2, 0), (3, 2, 1)]],
         )
 
+    def test_output_files_cwd(self):
+        dirname = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
+        os.makedirs(dirname, exist_ok=True)
+        file_stdout = os.path.join(dirname, "flux.out")
+        file_stderr = os.path.join(dirname, "flux.err")
+        with Executor(
+            max_cores=1,
+            resource_dict={"cores": 1, "cwd": dirname},
+            flux_executor=self.executor,
+            backend="flux_allocation",
+            block_allocation=True,
+            flux_log_files=True,
+        ) as p:
+            output = p.map(calc, [1, 2, 3])
+        self.assertEqual(
+            list(output),
+            [1, 2, 3],
+        )
+        self.assertTrue(os.path.exists(file_stdout))
+        self.assertTrue(os.path.exists(file_stderr))
+        os.remove(file_stdout)
+        os.remove(file_stderr)
+
+    def test_output_files_abs(self):
+        file_stdout = os.path.abspath("flux.out")
+        file_stderr = os.path.abspath("flux.err")
+        with Executor(
+            max_cores=1,
+            resource_dict={"cores": 1},
+            flux_executor=self.executor,
+            backend="flux_allocation",
+            block_allocation=True,
+            flux_log_files=True,
+        ) as p:
+            output = p.map(calc, [1, 2, 3])
+        self.assertEqual(
+            list(output),
+            [1, 2, 3],
+        )
+        self.assertTrue(os.path.exists(file_stdout))
+        self.assertTrue(os.path.exists(file_stderr))
+        os.remove(file_stdout)
+        os.remove(file_stderr)
+
     def test_internal_memory(self):
         with Executor(
             max_cores=1,
-            cores_per_worker=1,
+            resource_dict={"cores": 1},
             init_function=set_global,
             flux_executor=self.executor,
-            backend="flux",
+            backend="flux_allocation",
             block_allocation=True,
         ) as p:
             f = p.submit(get_global)
             self.assertFalse(f.done())
             self.assertEqual(f.result(), np.array([5]))
             self.assertTrue(f.done())
+
+    def test_validate_max_workers(self):
+        with self.assertRaises(ValueError):
+            Executor(
+                max_workers=10,
+                resource_dict={"cores": 10, "threads_per_core": 10},
+                flux_executor=self.executor,
+                backend="flux_allocation",
+                block_allocation=True,
+            )
