@@ -2,22 +2,27 @@ from concurrent.futures import CancelledError, Future
 import importlib.util
 from queue import Queue
 from time import sleep
+import shutil
 import unittest
 
 import numpy as np
 
-from executorlib.shared.spawner import MpiExecSpawner
-from executorlib.interactive.executor import (
+from executorlib.base.executor import ExecutorBase
+from executorlib.standalone.interactive.spawner import MpiExecSpawner
+from executorlib.interactive.shared import (
     InteractiveExecutor,
     InteractiveStepExecutor,
-)
-from executorlib.interactive.backend import call_funct
-from executorlib.shared.executor import (
-    cloudpickle_register,
     execute_parallel_tasks,
-    ExecutorBase,
 )
+from executorlib.standalone.interactive.backend import call_funct
+from executorlib.standalone.serialize import cloudpickle_register
 
+try:
+    import h5py
+
+    skip_h5py_test = False
+except ImportError:
+    skip_h5py_test = True
 
 skip_mpi4py_test = importlib.util.find_spec("mpi4py") is None
 
@@ -63,7 +68,7 @@ class TestPyMpiExecutorSerial(unittest.TestCase):
     def test_pympiexecutor_two_workers(self):
         with InteractiveExecutor(
             max_workers=2,
-            executor_kwargs={"hostname_localhost": True},
+            executor_kwargs={},
             spawner=MpiExecSpawner,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -77,7 +82,7 @@ class TestPyMpiExecutorSerial(unittest.TestCase):
     def test_pympiexecutor_one_worker(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"hostname_localhost": True},
+            executor_kwargs={},
             spawner=MpiExecSpawner,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -93,7 +98,7 @@ class TestPyMpiExecutorStepSerial(unittest.TestCase):
     def test_pympiexecutor_two_workers(self):
         with InteractiveStepExecutor(
             max_cores=2,
-            executor_kwargs={"hostname_localhost": True},
+            executor_kwargs={},
             spawner=MpiExecSpawner,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -107,7 +112,7 @@ class TestPyMpiExecutorStepSerial(unittest.TestCase):
     def test_pympiexecutor_one_worker(self):
         with InteractiveStepExecutor(
             max_cores=1,
-            executor_kwargs={"hostname_localhost": True},
+            executor_kwargs={},
             spawner=MpiExecSpawner,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -126,7 +131,7 @@ class TestPyMpiExecutorMPI(unittest.TestCase):
     def test_pympiexecutor_one_worker_with_mpi(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -137,7 +142,7 @@ class TestPyMpiExecutorMPI(unittest.TestCase):
     def test_pympiexecutor_one_worker_with_mpi_multiple_submissions(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             cloudpickle_register(ind=1)
@@ -157,7 +162,7 @@ class TestPyMpiExecutorMPI(unittest.TestCase):
     def test_pympiexecutor_one_worker_with_mpi_echo(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             cloudpickle_register(ind=1)
@@ -172,7 +177,7 @@ class TestPyMpiStepExecutorMPI(unittest.TestCase):
     def test_pympiexecutor_one_worker_with_mpi(self):
         with InteractiveStepExecutor(
             max_cores=2,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as exe:
             cloudpickle_register(ind=1)
@@ -183,7 +188,7 @@ class TestPyMpiStepExecutorMPI(unittest.TestCase):
     def test_pympiexecutor_one_worker_with_mpi_multiple_submissions(self):
         with InteractiveStepExecutor(
             max_cores=2,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             cloudpickle_register(ind=1)
@@ -203,7 +208,7 @@ class TestPyMpiStepExecutorMPI(unittest.TestCase):
     def test_pympiexecutor_one_worker_with_mpi_echo(self):
         with InteractiveStepExecutor(
             max_cores=2,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             cloudpickle_register(ind=1)
@@ -218,7 +223,6 @@ class TestPyMpiExecutorInitFunction(unittest.TestCase):
             executor_kwargs={
                 "cores": 1,
                 "init_function": set_global,
-                "hostname_localhost": True,
             },
             spawner=MpiExecSpawner,
         ) as p:
@@ -247,7 +251,6 @@ class TestPyMpiExecutorInitFunction(unittest.TestCase):
             cores=1,
             openmpi_oversubscribe=False,
             spawner=MpiExecSpawner,
-            hostname_localhost=True,
             init_function=set_global,
         )
         self.assertEqual(f.result(), np.array([5]))
@@ -258,7 +261,7 @@ class TestFuturePool(unittest.TestCase):
     def test_pool_serial(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 1, "hostname_localhost": True},
+            executor_kwargs={"cores": 1},
             spawner=MpiExecSpawner,
         ) as p:
             output = p.submit(calc_array, i=2)
@@ -273,7 +276,7 @@ class TestFuturePool(unittest.TestCase):
     def test_executor_multi_submission(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 1, "hostname_localhost": True},
+            executor_kwargs={"cores": 1},
             spawner=MpiExecSpawner,
         ) as p:
             fs_1 = p.submit(calc_array, i=2)
@@ -286,7 +289,7 @@ class TestFuturePool(unittest.TestCase):
     def test_shutdown(self):
         p = InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 1, "hostname_localhost": True},
+            executor_kwargs={"cores": 1},
             spawner=MpiExecSpawner,
         )
         fs1 = p.submit(sleep_one, i=2)
@@ -302,7 +305,7 @@ class TestFuturePool(unittest.TestCase):
     def test_pool_serial_map(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 1, "hostname_localhost": True},
+            executor_kwargs={"cores": 1},
             spawner=MpiExecSpawner,
         ) as p:
             output = p.map(calc_array, [1, 2, 3])
@@ -312,7 +315,7 @@ class TestFuturePool(unittest.TestCase):
         with self.assertRaises(RuntimeError):
             with InteractiveExecutor(
                 max_workers=1,
-                executor_kwargs={"cores": 1, "hostname_localhost": True},
+                executor_kwargs={"cores": 1},
                 spawner=MpiExecSpawner,
             ) as p:
                 p.submit(raise_error)
@@ -321,7 +324,7 @@ class TestFuturePool(unittest.TestCase):
         with self.assertRaises(RuntimeError):
             with InteractiveExecutor(
                 max_workers=1,
-                executor_kwargs={"cores": 1, "hostname_localhost": True},
+                executor_kwargs={"cores": 1},
                 spawner=MpiExecSpawner,
             ) as p:
                 fs = p.submit(raise_error)
@@ -333,7 +336,7 @@ class TestFuturePool(unittest.TestCase):
     def test_meta(self):
         meta_data_exe_dict = {
             "cores": 2,
-            "spawner": "<class 'executorlib.shared.spawner.MpiExecSpawner'>",
+            "spawner": "<class 'executorlib.standalone.interactive.spawner.MpiExecSpawner'>",
             "hostname_localhost": True,
             "init_function": None,
             "cwd": None,
@@ -362,7 +365,7 @@ class TestFuturePool(unittest.TestCase):
     def test_meta_step(self):
         meta_data_exe_dict = {
             "cores": 2,
-            "spawner": "<class 'executorlib.shared.spawner.MpiExecSpawner'>",
+            "spawner": "<class 'executorlib.standalone.interactive.spawner.MpiExecSpawner'>",
             "hostname_localhost": True,
             "cwd": None,
             "openmpi_oversubscribe": False,
@@ -390,14 +393,14 @@ class TestFuturePool(unittest.TestCase):
     def test_pool_multi_core(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             output = p.submit(mpi_funct, i=2)
             self.assertEqual(len(p), 1)
             self.assertTrue(isinstance(output, Future))
             self.assertFalse(output.done())
-            sleep(1)
+            sleep(2)
             self.assertTrue(output.done())
             self.assertEqual(len(p), 0)
         self.assertEqual(output.result(), [(2, 2, 0), (2, 2, 1)])
@@ -408,7 +411,7 @@ class TestFuturePool(unittest.TestCase):
     def test_pool_multi_core_map(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"cores": 2, "hostname_localhost": True},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             output = p.map(mpi_funct, [1, 2, 3])
@@ -428,7 +431,6 @@ class TestFuturePool(unittest.TestCase):
                 cores=1,
                 openmpi_oversubscribe=False,
                 spawner=MpiExecSpawner,
-                hostname_localhost=True,
             )
         q.join()
 
@@ -443,7 +445,6 @@ class TestFuturePool(unittest.TestCase):
                 cores=1,
                 openmpi_oversubscribe=False,
                 spawner=MpiExecSpawner,
-                hostname_localhost=True,
             )
         q.join()
 
@@ -458,7 +459,6 @@ class TestFuturePool(unittest.TestCase):
             cores=1,
             openmpi_oversubscribe=False,
             spawner=MpiExecSpawner,
-            hostname_localhost=True,
         )
         self.assertEqual(f.result(), np.array(4))
         q.join()
@@ -477,7 +477,48 @@ class TestFuturePool(unittest.TestCase):
             cores=2,
             openmpi_oversubscribe=False,
             spawner=MpiExecSpawner,
-            hostname_localhost=True,
         )
         self.assertEqual(f.result(), [np.array(4), np.array(4)])
         q.join()
+
+
+class TestFuturePoolCache(unittest.TestCase):
+    def tearDown(self):
+        shutil.rmtree("./cache")
+
+    @unittest.skipIf(
+        skip_h5py_test, "h5py is not installed, so the h5py tests are skipped."
+    )
+    def test_execute_task_cache(self):
+        f = Future()
+        q = Queue()
+        q.put({"fn": calc, "args": (), "kwargs": {"i": 1}, "future": f})
+        q.put({"shutdown": True, "wait": True})
+        cloudpickle_register(ind=1)
+        execute_parallel_tasks(
+            future_queue=q,
+            cores=1,
+            openmpi_oversubscribe=False,
+            spawner=MpiExecSpawner,
+            cache_directory="./cache",
+        )
+        self.assertEqual(f.result(), 1)
+        q.join()
+
+    @unittest.skipIf(
+        skip_h5py_test, "h5py is not installed, so the h5py tests are skipped."
+    )
+    def test_execute_task_cache_failed_no_argument(self):
+        f = Future()
+        q = Queue()
+        q.put({"fn": calc_array, "args": (), "kwargs": {}, "future": f})
+        cloudpickle_register(ind=1)
+        with self.assertRaises(TypeError):
+            execute_parallel_tasks(
+                future_queue=q,
+                cores=1,
+                openmpi_oversubscribe=False,
+                spawner=MpiExecSpawner,
+                cache_directory="./cache",
+            )
+        q.join()
