@@ -5,8 +5,8 @@ import unittest
 
 import numpy as np
 
-from executorlib.interactive.executor import InteractiveExecutor
-from executorlib.shared.spawner import MpiExecSpawner
+from executorlib.interactive.shared import InteractiveExecutor
+from executorlib.standalone.interactive.spawner import MpiExecSpawner
 
 
 skip_mpi4py_test = importlib.util.find_spec("mpi4py") is None
@@ -20,7 +20,7 @@ class TestFuture(unittest.TestCase):
     def test_pool_serial(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"hostname_localhost": True, "cores": 1},
+            executor_kwargs={"cores": 1},
             spawner=MpiExecSpawner,
         ) as p:
             output = p.submit(calc, i=2)
@@ -36,7 +36,7 @@ class TestFuture(unittest.TestCase):
     def test_pool_serial_multi_core(self):
         with InteractiveExecutor(
             max_workers=1,
-            executor_kwargs={"hostname_localhost": True, "cores": 2},
+            executor_kwargs={"cores": 2},
             spawner=MpiExecSpawner,
         ) as p:
             output = p.submit(calc, i=2)
@@ -68,7 +68,8 @@ class TestFuture(unittest.TestCase):
                 # Executor only exists in this scope and can get garbage collected after
                 # this function is exits
                 future = InteractiveExecutor(
-                    executor_kwargs={"hostname_localhost": True},
+                    max_workers=1,
+                    executor_kwargs={},
                     spawner=MpiExecSpawner,
                 ).submit(slow_callable)
                 future.add_done_callback(callback)
@@ -108,7 +109,8 @@ class TestFuture(unittest.TestCase):
                     self.running = True
 
                     future = InteractiveExecutor(
-                        executor_kwargs={"hostname_localhost": True},
+                        max_workers=1,
+                        executor_kwargs={},
                         spawner=MpiExecSpawner,
                     ).submit(self.return_42)
                     future.add_done_callback(self.finished)
